# Code of Conduct

At Giga, we're committed to maintaining an environment that's respectful, inclusive, and harassment-free for everyone involved in our project and community. We welcome contributors and participants from diverse backgrounds and pledge to uphold these standards:

## Our Pledge​

We promise to ensure a welcoming environment, regardless of:

- Age
- Body size
- Disability
- Ethnicity
- Gender identity and expression
- Level of experience
- Education
- Socio-economic status
- Nationality
- Personal appearance
- Race
- Religion
- Sexual identity and orientation

## Our Standards​

Examples of behavior that contributes to creating a positive environment include:

- Using language that's welcoming and inclusive
- Respecting differing viewpoints and experiences
- Embracing constructive criticism gracefully
- Prioritizing the well-being of the community
- Showing empathy towards fellow community members

Examples of unacceptable behavior by participants include:

- Using sexualized language or imagery, or making unwelcome advances
- Engaging in trolling, derogatory comments, or personal attacks
- Harassment in public or private spaces
- Publishing others' private information without explicit consent
- Any conduct that could be deemed inappropriate in a professional setting

## Our Responsibilities​

Project maintainers are entrusted with defining and upholding acceptable behavior standards. They have the authority to:

- Clarify the standards of acceptable behavior
- Take fair and appropriate action in response to unacceptable behavior
- Remove, edit, or reject contributions that violate the Code of Conduct
- Temporarily or permanently ban contributors engaging in inappropriate, offensive, or harmful behavior

## Scope​

This Code of Conduct applies within project spaces and when representing the project or community publicly. This representation includes using official project communication channels, social media, or acting as a representative at online/offline events. Project maintainers will define and clarify what constitutes representation.

## Enforcement and Reporting​

Instances of abusive, harassing, or otherwise unacceptable behavior may be reported to the community leaders responsible for enforcement at [giga@unicef.org](mailto:giga@unicef.org). All complaints will be reviewed and investigated promptly and fairly.

All community leaders are obligated to respect the privacy and security of the reporter of any incident.

## Community Spaces​

- Twitter
- Gigas' Website
- Discord
- Mail

## Enforcement Guidelines​

Community leaders will follow these Community Impact Guidelines in determining the consequences for any action they deem in violation of this Code of Conduct:

- **Correction**
  - Community Impact: Use of inappropriate language or other behavior deemed unprofessional or unwelcome in the community.
  - Consequence: A private, written warning from community leaders, providing clarity around the nature of the violation and an explanation of why the behavior was inappropriate. A public apology may be requested.
- **Warning**
  - Community Impact: A violation through a single incident or series of actions.
  - Consequence: A warning with consequences for continued behavior. No interaction with the people involved, including unsolicited interaction with those enforcing the Code of Conduct, for a specified period of time. This includes avoiding interactions in community spaces as well as external channels like social media. Violating these terms may lead to a temporary or permanent ban.
- **Temporary Ban**
  - Community Impact: A serious violation of community standards, including sustained inappropriate behavior.
  - Consequence: A temporary ban from any sort of interaction or public communication with the community for a specified period of time. No public or private interaction with the people involved, including unsolicited interaction with those enforcing the Code of Conduct, is allowed during this period. Violating these terms may lead to a permanent ban.
- **Permanent Ban**
  - Community Impact: Demonstrating a pattern of violation of community standards, including sustained inappropriate behavior, harassment of an individual, or aggression toward or disparagement of classes of individuals.
  - Consequence: A permanent ban from any sort of public interaction within the community.

## Attribution​

This Code of Conduct is adapted from  the [Contributor Covenant code of conduct](https://www.contributor-covenant.org/version/2/1/code_of_conduct/).